# Various test examples

http://progenetix.test/beacon/biosamples/?datasetIds=progenetix&referenceName=refseq:NC_000009.12&variantType=EFO:0030067&start=21500000&start=21975098&end=21967753&end=22500000&filters=NCIT:C3058

http://progenetix.org/beacon/genomicVariations/?referenceName=NC_000017.11&start=7577120&referenceBases=G&alternateBases=A

https://progenetix.org/beacon/g_variants/?filters=NCIT:C7712&output=pgxseg

https://progenetix.org/beacon/analyses/?referenceName=17&variantType=DEL&start=5000000&start=7676592&end=7669607&end=10000000&filters=&output=pgxmatrix

https://progenetix.org/beacon/analyses?referenceName=17&variantType=DEL&start=5000000&start=7676592&end=7669607&end=10000000&filters=cellosaurus&output=pgxmatrix

http://progenetix.org/beacon/biosamples?filters=NCIT:C3697&output=table

http://progenetix.org/beacon/biosamples?referenceName=9&start=10000000,12000000&end=12500000,15000000&variantType=DEL&filters=pgx:icdom-81703

http://progenetix.org/beacon/biosamples/onekgbs-HG00142/g_variants

http://progenetix.org/beacon/biosamples/pgxbs-kftvhyvb/phenopackets

http://progenetix.org/services/sampleplots/pgxbs-kftvkafc/?datasetIds=progenetix&plotType=samplesplot&plot_chros=3,5,6,14

